rpy2: Python interface to R
===========================

Description
-----------

rpy2 is a redesign and rewrite of rpy. It is providing a low-level
interface to R, a proposed high-level interface, including wrappers to
graphical libraries, as well as R-like structures and functions.

License
-------

-  GPL 2+

Upstream Contact
----------------

- https://github.com/rpy2/rpy2

Special Installation Instructions
---------------------------------

In the Sage distribution, ``rpy2`` is a "semi-standard" package: It will be
automatically installed by the Sage distribution if a suitable system
installation of R is detected by ``configure``. (Note that Sage no longer
ships and installs its own copy of R.)
